// Wrapper module to make up for changes in signal names between versions
// 1.6 and 3.0 of Xilinx' Integrated Block for PCIe.

module pcie_v7_8x 
  #(parameter PCIE_EXT_CLK = "TRUE")
(
   output [7:0]    pci_exp_txn,
   output [7:0]    pci_exp_txp,
   input [7:0] 	   pci_exp_rxn,
   input [7:0] 	   pci_exp_rxp,

   input 	   PIPE_PCLK_IN,
   input 	   PIPE_RXUSRCLK_IN,
   input [7:0] 	   PIPE_RXOUTCLK_IN,
   input 	   PIPE_DCLK_IN,
   input 	   PIPE_USERCLK1_IN,
   input 	   PIPE_USERCLK2_IN,
   input 	   PIPE_OOBCLK_IN,
   input 	   PIPE_MMCM_LOCK_IN,

   output 	   PIPE_TXOUTCLK_OUT,
   output [7:0]    PIPE_RXOUTCLK_OUT,
   output [7:0]    PIPE_PCLK_SEL_OUT,
   output 	   PIPE_GEN3_OUT,

   output 	   user_clk,
   output 	   user_reset,
   output 	   user_lnk_up,
   
   input 	   s_axis_rq_tlast,
   input [63:0]    s_axis_rq_tdata,
   input [59:0]    s_axis_rq_tuser,
   input [1:0] 	   s_axis_rq_tkeep,
   output [3:0]    s_axis_rq_tready,
   input 	   s_axis_rq_tvalid,

   output [63:0]   m_axis_rc_tdata,
   output [74:0]   m_axis_rc_tuser,
   output 	   m_axis_rc_tlast,
   output [1:0]    m_axis_rc_tkeep,
   output 	   m_axis_rc_tvalid,
   input [21:0]    m_axis_rc_tready,

   output [63:0]   m_axis_cq_tdata,
   output [84:0]   m_axis_cq_tuser,
   output 	   m_axis_cq_tlast,
   output [1:0]    m_axis_cq_tkeep,
   output 	   m_axis_cq_tvalid,
   input [21:0]    m_axis_cq_tready,

   input [63:0]    s_axis_cc_tdata,
   input [32:0]    s_axis_cc_tuser,
   input 	   s_axis_cc_tlast,
   input [1:0] 	   s_axis_cc_tkeep,
   input 	   s_axis_cc_tvalid,
   output [3:0]    s_axis_cc_tready,

   output [3:0]    pcie_rq_seq_num,
   output 	   pcie_rq_seq_num_vld,
   output [5:0]    pcie_rq_tag,
   output 	   pcie_rq_tag_vld,
   output [1:0]    pcie_tfc_nph_av,
   output [1:0]    pcie_tfc_npd_av,
   input 	   pcie_cq_np_req,
   output [5:0]    pcie_cq_np_req_count,

   output 	   cfg_phy_link_down,
   output [1:0]    cfg_phy_link_status,
   output [3:0]    cfg_negotiated_width,
   output [2:0]    cfg_current_speed,
   output [2:0]    cfg_max_payload,
   output [2:0]    cfg_max_read_req,
   output [7:0]    cfg_function_status,
   output [5:0]    cfg_function_power_state,
   output [11:0]   cfg_vf_status,
   output [17:0]   cfg_vf_power_state,
   output [1:0]    cfg_link_power_state,
   output 	   cfg_err_cor_out,
   output 	   cfg_err_nonfatal_out,
   output 	   cfg_err_fatal_out,
   output 	   cfg_ltr_enable,
   output [5:0]    cfg_ltssm_state,
   output [1:0]    cfg_rcb_status,
   output [1:0]    cfg_dpa_substate_change,
   output [1:0]    cfg_obff_enable,
   output 	   cfg_pl_status_change,
   output [1:0]    cfg_tph_requester_enable,
   output [5:0]    cfg_tph_st_mode,
   output [5:0]    cfg_vf_tph_requester_enable,
   output [17:0]   cfg_vf_tph_st_mode,

   output [7:0]    cfg_fc_ph,
   output [11:0]   cfg_fc_pd,
   output [7:0]    cfg_fc_nph,
   output [11:0]   cfg_fc_npd,
   output [7:0]    cfg_fc_cplh,
   output [11:0]   cfg_fc_cpld,
   input [2:0] 	   cfg_fc_sel,

   input [2:0] 	   cfg_per_function_number,
   input 	   cfg_per_function_output_request,
   output 	   cfg_per_function_update_done,
   input [63:0]    cfg_dsn,
   input 	   cfg_power_state_change_ack,
   output 	   cfg_power_state_change_interrupt,
   input 	   cfg_err_cor_in,
   input 	   cfg_err_uncor_in,
   output [1:0]    cfg_flr_in_process,
   input [1:0] 	   cfg_flr_done,
   output [5:0]    cfg_vf_flr_in_process,
   input [5:0] 	   cfg_vf_flr_done,
   input 	   cfg_link_training_enable,
   input [7:0] 	   cfg_ds_port_number,

   input [3:0] 	   cfg_interrupt_int,
   input [1:0] 	   cfg_interrupt_pending,
   output 	   cfg_interrupt_sent,
   output [1:0]    cfg_interrupt_msi_enable,
   output [5:0]    cfg_interrupt_msi_vf_enable,
   output [5:0]    cfg_interrupt_msi_mmenable,
   output 	   cfg_interrupt_msi_mask_update,
   output [31:0]   cfg_interrupt_msi_data,
   input [3:0] 	   cfg_interrupt_msi_select,
   input [31:0]    cfg_interrupt_msi_int,
   input [63:0]    cfg_interrupt_msi_pending_status,
   output 	   cfg_interrupt_msi_sent,
   output 	   cfg_interrupt_msi_fail,
   output [1:0]    cfg_interrupt_msix_enable,
   output [1:0]    cfg_interrupt_msix_mask,
   output [5:0]    cfg_interrupt_msix_vf_enable,
   output [5:0]    cfg_interrupt_msix_vf_mask,
   input [31:0]    cfg_interrupt_msix_data,
   input [63:0]    cfg_interrupt_msix_address,
   input 	   cfg_interrupt_msix_int,
   output 	   cfg_interrupt_msix_sent,
   output 	   cfg_interrupt_msix_fail,
   input [2:0] 	   cfg_interrupt_msi_attr,
   input 	   cfg_interrupt_msi_tph_present,
   input [1:0] 	   cfg_interrupt_msi_tph_type,
   input [8:0] 	   cfg_interrupt_msi_tph_st_tag,
   input [2:0] 	   cfg_interrupt_msi_function_number,

   output 	   cfg_hot_reset_out,
   input 	   cfg_config_space_enable,
   input 	   cfg_req_pm_transition_l23_ready,
   input 	   cfg_hot_reset_in,
   input [7:0] 	   cfg_ds_bus_number,
   input [4:0] 	   cfg_ds_device_number,
   input [2:0] 	   cfg_ds_function_number,
   input 	   conf_clk,

   input 	   ICAP_ceb_user,
   input 	   ICAP_wrb_user,
   input [31:0]    ICAP_din_bs_user,
   output [31:0]   ICAP_dout_user,

   input 	   sys_clk,
   input 	   sys_reset,
   input           pipe_mmcm_rst_n,
 
   input [7:0] 	   init_pattern_bus,
   input [4:0] 	   user_tph_stt_address,
   input [2:0] 	   user_tph_function_num,
   output [31:0]   user_tph_stt_read_data,
   output 	   user_tph_stt_read_data_valid,
   input 	   user_tph_stt_read_enable
);
   
pcie_v7_vivado pcie_v7_vivado
  (
   .pci_exp_txp(pci_exp_txp),
   .pci_exp_txn(pci_exp_txn),
   .pci_exp_rxp(pci_exp_rxp),
   .pci_exp_rxn(pci_exp_rxn),
   .pipe_pclk_in(PIPE_PCLK_IN),
   .pipe_rxusrclk_in(PIPE_RXUSRCLK_IN),
   .pipe_rxoutclk_in(PIPE_RXOUTCLK_IN),
   .pipe_dclk_in(PIPE_DCLK_IN),
   .pipe_userclk1_in(PIPE_USERCLK1_IN),
   .pipe_userclk2_in(PIPE_USERCLK2_IN),
   .pipe_oobclk_in(PIPE_OOBCLK_IN),
   .pipe_mmcm_lock_in(PIPE_MMCM_LOCK_IN),
   .pipe_txoutclk_out(PIPE_TXOUTCLK_OUT),
   .pipe_rxoutclk_out(PIPE_RXOUTCLK_OUT),
   .pipe_pclk_sel_out(PIPE_PCLK_SEL_OUT),
   .pipe_gen3_out(PIPE_GEN3_OUT),

   .user_clk(user_clk),
   .user_reset(user_reset),
   .user_lnk_up(user_lnk_up),
   .user_app_rdy(user_app_rdy),
   .s_axis_rq_tlast(s_axis_rq_tlast),
   .s_axis_rq_tdata(s_axis_rq_tdata),
   .s_axis_rq_tuser(s_axis_rq_tuser),
   .s_axis_rq_tkeep(s_axis_rq_tkeep),
   .s_axis_rq_tready(s_axis_rq_tready),
   .s_axis_rq_tvalid(s_axis_rq_tvalid),
   .m_axis_rc_tdata(m_axis_rc_tdata),
   .m_axis_rc_tuser(m_axis_rc_tuser),
   .m_axis_rc_tlast(m_axis_rc_tlast),
   .m_axis_rc_tkeep(m_axis_rc_tkeep),
   .m_axis_rc_tvalid(m_axis_rc_tvalid),
   .m_axis_rc_tready(m_axis_rc_tready),
   .m_axis_cq_tdata(m_axis_cq_tdata),
   .m_axis_cq_tuser(m_axis_cq_tuser),
   .m_axis_cq_tlast(m_axis_cq_tlast),
   .m_axis_cq_tkeep(m_axis_cq_tkeep),
   .m_axis_cq_tvalid(m_axis_cq_tvalid),
   .m_axis_cq_tready(m_axis_cq_tready),
   .s_axis_cc_tdata(s_axis_cc_tdata),
   .s_axis_cc_tuser(s_axis_cc_tuser),
   .s_axis_cc_tlast(s_axis_cc_tlast),
   .s_axis_cc_tkeep(s_axis_cc_tkeep),
   .s_axis_cc_tvalid(s_axis_cc_tvalid),
   .s_axis_cc_tready(s_axis_cc_tready),

   .pcie_tfc_nph_av(pcie_tfc_nph_av),
   .pcie_tfc_npd_av(pcie_tfc_npd_av),
   .pcie_rq_seq_num(pcie_rq_seq_num),
   .pcie_rq_seq_num_vld(pcie_rq_seq_num_vld),
   .pcie_rq_tag(pcie_rq_tag),
   .pcie_rq_tag_vld(pcie_rq_tag_vld),
   .pcie_cq_np_req(pcie_cq_np_req),
   .pcie_cq_np_req_count(pcie_cq_np_req_count),
   .cfg_phy_link_down(cfg_phy_link_down),
   .cfg_phy_link_status(cfg_phy_link_status),
   .cfg_negotiated_width(cfg_negotiated_width),
   .cfg_current_speed(cfg_current_speed),
   .cfg_max_payload(cfg_max_payload),
   .cfg_max_read_req(cfg_max_read_req),
   .cfg_function_status(cfg_function_status),
   .cfg_function_power_state(cfg_function_power_state),
   .cfg_vf_status(cfg_vf_status),
   .cfg_vf_power_state(cfg_vf_power_state),
   .cfg_link_power_state(cfg_link_power_state),
   .cfg_err_cor_out(cfg_err_cor_out),
   .cfg_err_nonfatal_out(cfg_err_nonfatal_out),
   .cfg_err_fatal_out(cfg_err_fatal_out),
   .cfg_ltr_enable(cfg_ltr_enable),
   .cfg_ltssm_state(cfg_ltssm_state),
   .cfg_rcb_status(cfg_rcb_status),
   .cfg_dpa_substate_change(cfg_dpa_substate_change),
   .cfg_obff_enable(cfg_obff_enable),
   .cfg_pl_status_change(cfg_pl_status_change),
   .cfg_tph_requester_enable(cfg_tph_requester_enable),
   .cfg_tph_st_mode(cfg_tph_st_mode),
   .cfg_vf_tph_requester_enable(cfg_vf_tph_requester_enable),
   .cfg_vf_tph_st_mode(cfg_vf_tph_st_mode),
   .cfg_fc_ph(cfg_fc_ph),
   .cfg_fc_pd(cfg_fc_pd),
   .cfg_fc_nph(cfg_fc_nph),
   .cfg_fc_npd(cfg_fc_npd),
   .cfg_fc_cplh(cfg_fc_cplh),
   .cfg_fc_cpld(cfg_fc_cpld),
   .cfg_fc_sel(cfg_fc_sel),
   .cfg_hot_reset_out(cfg_hot_reset_out),
   .cfg_config_space_enable(cfg_config_space_enable),
   .cfg_req_pm_transition_l23_ready(cfg_req_pm_transition_l23_ready),
   .cfg_hot_reset_in(cfg_hot_reset_in),
   .cfg_ds_port_number(cfg_ds_port_number),
   .cfg_ds_bus_number(cfg_ds_bus_number),
   .cfg_ds_device_number(cfg_ds_device_number),
   .cfg_ds_function_number(cfg_ds_function_number),
   .cfg_per_function_number(cfg_per_function_number),
   .cfg_per_function_output_request(cfg_per_function_output_request),
   .cfg_per_function_update_done(cfg_per_function_update_done),
   .cfg_dsn(cfg_dsn),
   .cfg_power_state_change_ack(cfg_power_state_change_ack),
   .cfg_power_state_change_interrupt(cfg_power_state_change_interrupt),
   .cfg_err_cor_in(cfg_err_cor_in),
   .cfg_err_uncor_in(cfg_err_uncor_in),
   .cfg_flr_in_process(cfg_flr_in_process),
   .cfg_flr_done(cfg_flr_done),
   .cfg_vf_flr_in_process(cfg_vf_flr_in_process),
   .cfg_vf_flr_done(cfg_vf_flr_done),
   .cfg_link_training_enable(cfg_link_training_enable),
   .cfg_interrupt_int(cfg_interrupt_int),
   .cfg_interrupt_pending(cfg_interrupt_pending),
   .cfg_interrupt_sent(cfg_interrupt_sent),
   .cfg_interrupt_msi_enable(cfg_interrupt_msi_enable),
   .cfg_interrupt_msi_vf_enable(cfg_interrupt_msi_vf_enable),
   .cfg_interrupt_msi_mmenable(cfg_interrupt_msi_mmenable),
   .cfg_interrupt_msi_mask_update(cfg_interrupt_msi_mask_update),
   .cfg_interrupt_msi_data(cfg_interrupt_msi_data),
   .cfg_interrupt_msi_select(cfg_interrupt_msi_select),
   .cfg_interrupt_msi_int(cfg_interrupt_msi_int),
   .cfg_interrupt_msi_pending_status(cfg_interrupt_msi_pending_status),
   .cfg_interrupt_msi_sent(cfg_interrupt_msi_sent),
   .cfg_interrupt_msi_fail(cfg_interrupt_msi_fail),
   .cfg_interrupt_msi_attr(cfg_interrupt_msi_attr),
   .cfg_interrupt_msi_tph_present(cfg_interrupt_msi_tph_present),
   .cfg_interrupt_msi_tph_type(cfg_interrupt_msi_tph_type),
   .cfg_interrupt_msi_tph_st_tag(cfg_interrupt_msi_tph_st_tag),
   .cfg_interrupt_msi_function_number(cfg_interrupt_msi_function_number),
   .cfg_subsys_vend_id(16'h10EE), // New input. Hardcoded Vendor ID.

   .sys_clk(sys_clk),
   .sys_reset(sys_reset),
   .pipe_mmcm_rst_n(pipe_mmcm_rst_n)
   );
endmodule
